@@ -30,6 +30,8 @@ class Mongodb:
     INTEGRATION_ORG = 'integration_org'
     OFFERS_TARGETGROUP_COLLECTION = 'offers_targetgroups'
     APP_USERS_MANAGEMENT_COLLECTION = 'app_user_management'
+    AURA_SUBSCRIPTIONS_COLLECTION = "aura_subscriptions"
+    AURA_NOTIFICATIONS = 'aura_notifications'
     UPSWING_INTEGRATIONS = 'integrations'
 
 
