@@ -170,9 +170,9 @@ def _retrieve_data(session, id, name, url):
 
 
 def _trigger_email(record: ReservationModelV2):
+    mongo = Mongodb(record.orgId)
     try:
-        if record.status == Status.CONFIRMED or record.status == Status.CREATED:
-            mongo = Mongodb(record.orgId)
+        if record.status == Status.CONFIRMED:
             _property = mongo.get_collection(mongo.PROPERTY_COLLECTION).find_one(
                 {'_id': record.idObj.hotelId, 'hotelId': record.idObj.hotelId})
             __pipeline__ = [
